@@ -17,9 +17,9 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with deluge.    If not, write to:
-# 	The Free Software Foundation, Inc.,
-# 	51 Franklin Street, Fifth Floor
-# 	Boston, MA  02110-1301, USA.
+#   The Free Software Foundation, Inc.,
+#   51 Franklin Street, Fifth Floor
+#   Boston, MA  02110-1301, USA.
 #
 #    In addition, as a special exception, the copyright holders give
 #    permission to link the code of portions of this program with the OpenSSL
@@ -281,7 +281,7 @@ class FilesTab(Tab):
             state_file = open(os.path.join(config_location, filename), "rb")
             state = cPickle.load(state_file)
             state_file.close()
-        except (EOFError, IOError, AttributeError), e:
+        except (EOFError, IOError, AttributeError, cPickle.UnpicklingError), e:
             log.warning("Unable to load state file: %s", e)
 
         if state == None:
@@ -334,7 +334,7 @@ class FilesTab(Tab):
             log.debug("Getting file list from core..")
             status_keys += ["files"]
 
-        component.get("SessionProxy").get_torrent_status(self.torrent_id, status_keys).addCallback(self._on_get_torrent_status)
+        component.get("SessionProxy").get_torrent_status(self.torrent_id, status_keys).addCallback(self._on_get_torrent_status, self.torrent_id)
 
     def clear(self):
         self.treestore.clear()
@@ -464,7 +464,11 @@ class FilesTab(Tab):
 
         get_completed_bytes(self.treestore.iter_children(root))
 
-    def _on_get_torrent_status(self, status):
+    def _on_get_torrent_status(self, status, torrent_id):
+        # Check stored torrent id matches the callback id
+        if self.torrent_id != torrent_id:
+            return
+
         # Store this torrent's compact setting
         if "compact" in status:
             self.__compact = status["compact"]
@@ -822,7 +826,11 @@ class FilesTab(Tab):
         selection.set_text(cPickle.dumps(paths))
 
     def _on_drag_data_received_data(self, treeview, context, x, y, selection, info, etime):
-        selected = cPickle.loads(selection.data)
+        try:
+            selected = cPickle.loads(selection.data)
+        except cPickle.UnpicklingError:
+            log.debug("Invalid selection data: %s", selection.data)
+            return
         log.debug("selection.data: %s", selected)
         drop_info = treeview.get_dest_row_at_pos(x, y)
         model = treeview.get_model()
